These are examples of authentic standard libraries that can be used for annotation. 

They are generated using the CSV export method from CompoundDiscoverer. 

These should not be used for generic analyses since they are specific to our instruments and methods.